${ title }

<%inherit file="../base/base.html" /> <%namespace file="../base/base.html" import="header, setup_margin_labels" /> <%block name="title_head"> <%block name="extra_meta"> ${ setup_margin_labels(title) }
${ header(complete_header, title, report.subtitle, notes) }

${ _("Order Number") }: | ${ report.workorder.identifier }
% if report.workorder.sellable:
${ _("Equipment") }: | ${ report.workorder.sellable.description }
% endif
${ _("Description") }: | ${ report.workorder.description }
${ _("Client") }: | ${ report.workorder.client.person.name } | ${ _("Responsible") }: | ${ report.workorder.execution_responsible.get_description() if \ report.workorder.execution_responsible else '' }
${ _("Approval date") }: | ${ format_date(report.workorder.approve_date) } | ${ _("Finish date") }: | ${ format_date(report.workorder.finish_date) }

<%include file="workorder-items.html" />
${ report.workorder.client.get_description() }